/****************************************************************************
** Meta object code from reading C++ file 'kquickstyleitem_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/qqc2-desktop-style-5.43.0/plugin/kquickstyleitem_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kquickstyleitem_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KQuickStyleItem_t {
    QByteArrayData data[78];
    char stringdata0[899];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KQuickStyleItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KQuickStyleItem_t qt_meta_stringdata_KQuickStyleItem = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KQuickStyleItem"
QT_MOC_LITERAL(1, 16, 18), // "elementTypeChanged"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 11), // "textChanged"
QT_MOC_LITERAL(4, 48, 13), // "sunkenChanged"
QT_MOC_LITERAL(5, 62, 13), // "raisedChanged"
QT_MOC_LITERAL(6, 76, 13), // "activeChanged"
QT_MOC_LITERAL(7, 90, 15), // "selectedChanged"
QT_MOC_LITERAL(8, 106, 15), // "hasFocusChanged"
QT_MOC_LITERAL(9, 122, 9), // "onChanged"
QT_MOC_LITERAL(10, 132, 12), // "hoverChanged"
QT_MOC_LITERAL(11, 145, 17), // "horizontalChanged"
QT_MOC_LITERAL(12, 163, 16), // "transientChanged"
QT_MOC_LITERAL(13, 180, 14), // "minimumChanged"
QT_MOC_LITERAL(14, 195, 14), // "maximumChanged"
QT_MOC_LITERAL(15, 210, 11), // "stepChanged"
QT_MOC_LITERAL(16, 222, 12), // "valueChanged"
QT_MOC_LITERAL(17, 235, 20), // "activeControlChanged"
QT_MOC_LITERAL(18, 256, 11), // "infoChanged"
QT_MOC_LITERAL(19, 268, 12), // "styleChanged"
QT_MOC_LITERAL(20, 281, 19), // "paintMarginsChanged"
QT_MOC_LITERAL(21, 301, 11), // "hintChanged"
QT_MOC_LITERAL(22, 313, 17), // "propertiesChanged"
QT_MOC_LITERAL(23, 331, 11), // "fontChanged"
QT_MOC_LITERAL(24, 343, 14), // "controlChanged"
QT_MOC_LITERAL(25, 358, 19), // "contentWidthChanged"
QT_MOC_LITERAL(26, 378, 3), // "arg"
QT_MOC_LITERAL(27, 382, 20), // "contentHeightChanged"
QT_MOC_LITERAL(28, 403, 19), // "textureWidthChanged"
QT_MOC_LITERAL(29, 423, 1), // "w"
QT_MOC_LITERAL(30, 425, 20), // "textureHeightChanged"
QT_MOC_LITERAL(31, 446, 1), // "h"
QT_MOC_LITERAL(32, 448, 11), // "pixelMetric"
QT_MOC_LITERAL(33, 460, 9), // "styleHint"
QT_MOC_LITERAL(34, 470, 14), // "updateSizeHint"
QT_MOC_LITERAL(35, 485, 10), // "updateRect"
QT_MOC_LITERAL(36, 496, 20), // "updateBaselineOffset"
QT_MOC_LITERAL(37, 517, 10), // "updateItem"
QT_MOC_LITERAL(38, 528, 7), // "hitTest"
QT_MOC_LITERAL(39, 536, 1), // "x"
QT_MOC_LITERAL(40, 538, 1), // "y"
QT_MOC_LITERAL(41, 540, 14), // "subControlRect"
QT_MOC_LITERAL(42, 555, 16), // "subcontrolString"
QT_MOC_LITERAL(43, 572, 10), // "elidedText"
QT_MOC_LITERAL(44, 583, 4), // "text"
QT_MOC_LITERAL(45, 588, 9), // "elideMode"
QT_MOC_LITERAL(46, 598, 5), // "width"
QT_MOC_LITERAL(47, 604, 12), // "hasThemeIcon"
QT_MOC_LITERAL(48, 617, 9), // "textWidth"
QT_MOC_LITERAL(49, 627, 10), // "textHeight"
QT_MOC_LITERAL(50, 638, 6), // "border"
QT_MOC_LITERAL(51, 645, 14), // "KQuickPadding*"
QT_MOC_LITERAL(52, 660, 6), // "sunken"
QT_MOC_LITERAL(53, 667, 6), // "raised"
QT_MOC_LITERAL(54, 674, 6), // "active"
QT_MOC_LITERAL(55, 681, 8), // "selected"
QT_MOC_LITERAL(56, 690, 8), // "hasFocus"
QT_MOC_LITERAL(57, 699, 2), // "on"
QT_MOC_LITERAL(58, 702, 5), // "hover"
QT_MOC_LITERAL(59, 708, 10), // "horizontal"
QT_MOC_LITERAL(60, 719, 11), // "isTransient"
QT_MOC_LITERAL(61, 731, 11), // "elementType"
QT_MOC_LITERAL(62, 743, 13), // "activeControl"
QT_MOC_LITERAL(63, 757, 5), // "style"
QT_MOC_LITERAL(64, 763, 5), // "hints"
QT_MOC_LITERAL(65, 769, 10), // "properties"
QT_MOC_LITERAL(66, 780, 4), // "font"
QT_MOC_LITERAL(67, 785, 7), // "minimum"
QT_MOC_LITERAL(68, 793, 7), // "maximum"
QT_MOC_LITERAL(69, 801, 5), // "value"
QT_MOC_LITERAL(70, 807, 4), // "step"
QT_MOC_LITERAL(71, 812, 12), // "paintMargins"
QT_MOC_LITERAL(72, 825, 12), // "contentWidth"
QT_MOC_LITERAL(73, 838, 13), // "contentHeight"
QT_MOC_LITERAL(74, 852, 12), // "textureWidth"
QT_MOC_LITERAL(75, 865, 13), // "textureHeight"
QT_MOC_LITERAL(76, 879, 7), // "control"
QT_MOC_LITERAL(77, 887, 11) // "QQuickItem*"

    },
    "KQuickStyleItem\0elementTypeChanged\0\0"
    "textChanged\0sunkenChanged\0raisedChanged\0"
    "activeChanged\0selectedChanged\0"
    "hasFocusChanged\0onChanged\0hoverChanged\0"
    "horizontalChanged\0transientChanged\0"
    "minimumChanged\0maximumChanged\0stepChanged\0"
    "valueChanged\0activeControlChanged\0"
    "infoChanged\0styleChanged\0paintMarginsChanged\0"
    "hintChanged\0propertiesChanged\0fontChanged\0"
    "controlChanged\0contentWidthChanged\0"
    "arg\0contentHeightChanged\0textureWidthChanged\0"
    "w\0textureHeightChanged\0h\0pixelMetric\0"
    "styleHint\0updateSizeHint\0updateRect\0"
    "updateBaselineOffset\0updateItem\0hitTest\0"
    "x\0y\0subControlRect\0subcontrolString\0"
    "elidedText\0text\0elideMode\0width\0"
    "hasThemeIcon\0textWidth\0textHeight\0"
    "border\0KQuickPadding*\0sunken\0raised\0"
    "active\0selected\0hasFocus\0on\0hover\0"
    "horizontal\0isTransient\0elementType\0"
    "activeControl\0style\0hints\0properties\0"
    "font\0minimum\0maximum\0value\0step\0"
    "paintMargins\0contentWidth\0contentHeight\0"
    "textureWidth\0textureHeight\0control\0"
    "QQuickItem*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KQuickStyleItem[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      39,   14, // methods
      27,  278, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      27,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  209,    2, 0x06 /* Public */,
       3,    0,  210,    2, 0x06 /* Public */,
       4,    0,  211,    2, 0x06 /* Public */,
       5,    0,  212,    2, 0x06 /* Public */,
       6,    0,  213,    2, 0x06 /* Public */,
       7,    0,  214,    2, 0x06 /* Public */,
       8,    0,  215,    2, 0x06 /* Public */,
       9,    0,  216,    2, 0x06 /* Public */,
      10,    0,  217,    2, 0x06 /* Public */,
      11,    0,  218,    2, 0x06 /* Public */,
      12,    0,  219,    2, 0x06 /* Public */,
      13,    0,  220,    2, 0x06 /* Public */,
      14,    0,  221,    2, 0x06 /* Public */,
      15,    0,  222,    2, 0x06 /* Public */,
      16,    0,  223,    2, 0x06 /* Public */,
      17,    0,  224,    2, 0x06 /* Public */,
      18,    0,  225,    2, 0x06 /* Public */,
      19,    0,  226,    2, 0x06 /* Public */,
      20,    0,  227,    2, 0x06 /* Public */,
      21,    0,  228,    2, 0x06 /* Public */,
      22,    0,  229,    2, 0x06 /* Public */,
      23,    0,  230,    2, 0x06 /* Public */,
      24,    0,  231,    2, 0x06 /* Public */,
      25,    1,  232,    2, 0x06 /* Public */,
      27,    1,  235,    2, 0x06 /* Public */,
      28,    1,  238,    2, 0x06 /* Public */,
      30,    1,  241,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      32,    1,  244,    2, 0x0a /* Public */,
      33,    1,  247,    2, 0x0a /* Public */,
      34,    0,  250,    2, 0x0a /* Public */,
      35,    0,  251,    2, 0x0a /* Public */,
      36,    0,  252,    2, 0x0a /* Public */,
      37,    0,  253,    2, 0x0a /* Public */,
      38,    2,  254,    2, 0x0a /* Public */,
      41,    1,  259,    2, 0x0a /* Public */,
      43,    3,  262,    2, 0x0a /* Public */,
      47,    1,  269,    2, 0x0a /* Public */,

 // methods: name, argc, parameters, tag, flags
      48,    1,  272,    2, 0x02 /* Public */,
      49,    1,  275,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   26,
    QMetaType::Void, QMetaType::Int,   26,
    QMetaType::Void, QMetaType::Int,   29,
    QMetaType::Void, QMetaType::Int,   31,

 // slots: parameters
    QMetaType::Int, QMetaType::QString,    2,
    QMetaType::QVariant, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::QString, QMetaType::Int, QMetaType::Int,   39,   40,
    QMetaType::QRectF, QMetaType::QString,   42,
    QMetaType::QString, QMetaType::QString, QMetaType::Int, QMetaType::Int,   44,   45,   46,
    QMetaType::Bool, QMetaType::QString,    2,

 // methods: parameters
    QMetaType::QReal, QMetaType::QString,    2,
    QMetaType::QReal, QMetaType::QString,    2,

 // properties: name, type, flags
      50, 0x80000000 | 51, 0x00095409,
      52, QMetaType::Bool, 0x00495103,
      53, QMetaType::Bool, 0x00495103,
      54, QMetaType::Bool, 0x00495103,
      55, QMetaType::Bool, 0x00495103,
      56, QMetaType::Bool, 0x00495003,
      57, QMetaType::Bool, 0x00495103,
      58, QMetaType::Bool, 0x00495103,
      59, QMetaType::Bool, 0x00495103,
      60, QMetaType::Bool, 0x00495003,
      61, QMetaType::QString, 0x00495103,
      44, QMetaType::QString, 0x00495103,
      62, QMetaType::QString, 0x00495103,
      63, QMetaType::QString, 0x00495001,
      64, QMetaType::QVariantMap, 0x00495107,
      65, QMetaType::QVariantMap, 0x00495103,
      66, QMetaType::QFont, 0x00495001,
      67, QMetaType::Int, 0x00495103,
      68, QMetaType::Int, 0x00495103,
      69, QMetaType::Int, 0x00495103,
      70, QMetaType::Int, 0x00495103,
      71, QMetaType::Int, 0x00495103,
      72, QMetaType::Int, 0x00495103,
      73, QMetaType::Int, 0x00495103,
      74, QMetaType::Int, 0x00495103,
      75, QMetaType::Int, 0x00495103,
      76, 0x80000000 | 77, 0x0049510b,

 // properties: notify_signal_id
       0,
       2,
       3,
       4,
       5,
       6,
       7,
       8,
       9,
      10,
       0,
       1,
      15,
      17,
      19,
      20,
      21,
      11,
      12,
      14,
      13,
      18,
      23,
      24,
      25,
      26,
      22,

       0        // eod
};

void KQuickStyleItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KQuickStyleItem *_t = static_cast<KQuickStyleItem *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->elementTypeChanged(); break;
        case 1: _t->textChanged(); break;
        case 2: _t->sunkenChanged(); break;
        case 3: _t->raisedChanged(); break;
        case 4: _t->activeChanged(); break;
        case 5: _t->selectedChanged(); break;
        case 6: _t->hasFocusChanged(); break;
        case 7: _t->onChanged(); break;
        case 8: _t->hoverChanged(); break;
        case 9: _t->horizontalChanged(); break;
        case 10: _t->transientChanged(); break;
        case 11: _t->minimumChanged(); break;
        case 12: _t->maximumChanged(); break;
        case 13: _t->stepChanged(); break;
        case 14: _t->valueChanged(); break;
        case 15: _t->activeControlChanged(); break;
        case 16: _t->infoChanged(); break;
        case 17: _t->styleChanged(); break;
        case 18: _t->paintMarginsChanged(); break;
        case 19: _t->hintChanged(); break;
        case 20: _t->propertiesChanged(); break;
        case 21: _t->fontChanged(); break;
        case 22: _t->controlChanged(); break;
        case 23: _t->contentWidthChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 24: _t->contentHeightChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 25: _t->textureWidthChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 26: _t->textureHeightChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 27: { int _r = _t->pixelMetric((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 28: { QVariant _r = _t->styleHint((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariant*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->updateSizeHint(); break;
        case 30: _t->updateRect(); break;
        case 31: _t->updateBaselineOffset(); break;
        case 32: _t->updateItem(); break;
        case 33: { QString _r = _t->hitTest((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 34: { QRectF _r = _t->subControlRect((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QRectF*>(_a[0]) = std::move(_r); }  break;
        case 35: { QString _r = _t->elidedText((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->hasThemeIcon((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { qreal _r = _t->textWidth((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< qreal*>(_a[0]) = std::move(_r); }  break;
        case 38: { qreal _r = _t->textHeight((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< qreal*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::elementTypeChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::textChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::sunkenChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::raisedChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::activeChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::selectedChanged)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::hasFocusChanged)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::onChanged)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::hoverChanged)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::horizontalChanged)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::transientChanged)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::minimumChanged)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::maximumChanged)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::stepChanged)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::valueChanged)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::activeControlChanged)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::infoChanged)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::styleChanged)) {
                *result = 17;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::paintMarginsChanged)) {
                *result = 18;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::hintChanged)) {
                *result = 19;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::propertiesChanged)) {
                *result = 20;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::fontChanged)) {
                *result = 21;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::controlChanged)) {
                *result = 22;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::contentWidthChanged)) {
                *result = 23;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::contentHeightChanged)) {
                *result = 24;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::textureWidthChanged)) {
                *result = 25;
                return;
            }
        }
        {
            typedef void (KQuickStyleItem::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KQuickStyleItem::textureHeightChanged)) {
                *result = 26;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KQuickPadding* >(); break;
        case 26:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KQuickStyleItem *_t = static_cast<KQuickStyleItem *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< KQuickPadding**>(_v) = _t->border(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->sunken(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->raised(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->active(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->selected(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->hasFocus(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->on(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->hover(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->horizontal(); break;
        case 9: *reinterpret_cast< bool*>(_v) = _t->isTransient(); break;
        case 10: *reinterpret_cast< QString*>(_v) = _t->elementType(); break;
        case 11: *reinterpret_cast< QString*>(_v) = _t->text(); break;
        case 12: *reinterpret_cast< QString*>(_v) = _t->activeControl(); break;
        case 13: *reinterpret_cast< QString*>(_v) = _t->style(); break;
        case 14: *reinterpret_cast< QVariantMap*>(_v) = _t->hints(); break;
        case 15: *reinterpret_cast< QVariantMap*>(_v) = _t->properties(); break;
        case 16: *reinterpret_cast< QFont*>(_v) = _t->font(); break;
        case 17: *reinterpret_cast< int*>(_v) = _t->minimum(); break;
        case 18: *reinterpret_cast< int*>(_v) = _t->maximum(); break;
        case 19: *reinterpret_cast< int*>(_v) = _t->value(); break;
        case 20: *reinterpret_cast< int*>(_v) = _t->step(); break;
        case 21: *reinterpret_cast< int*>(_v) = _t->paintMargins(); break;
        case 22: *reinterpret_cast< int*>(_v) = _t->contentWidth(); break;
        case 23: *reinterpret_cast< int*>(_v) = _t->contentHeight(); break;
        case 24: *reinterpret_cast< int*>(_v) = _t->textureWidth(); break;
        case 25: *reinterpret_cast< int*>(_v) = _t->textureHeight(); break;
        case 26: *reinterpret_cast< QQuickItem**>(_v) = _t->control(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KQuickStyleItem *_t = static_cast<KQuickStyleItem *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setSunken(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setRaised(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setActive(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setSelected(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->sethasFocus(*reinterpret_cast< bool*>(_v)); break;
        case 6: _t->setOn(*reinterpret_cast< bool*>(_v)); break;
        case 7: _t->setHover(*reinterpret_cast< bool*>(_v)); break;
        case 8: _t->setHorizontal(*reinterpret_cast< bool*>(_v)); break;
        case 9: _t->setTransient(*reinterpret_cast< bool*>(_v)); break;
        case 10: _t->setElementType(*reinterpret_cast< QString*>(_v)); break;
        case 11: _t->setText(*reinterpret_cast< QString*>(_v)); break;
        case 12: _t->setActiveControl(*reinterpret_cast< QString*>(_v)); break;
        case 14: _t->setHints(*reinterpret_cast< QVariantMap*>(_v)); break;
        case 15: _t->setProperties(*reinterpret_cast< QVariantMap*>(_v)); break;
        case 17: _t->setMinimum(*reinterpret_cast< int*>(_v)); break;
        case 18: _t->setMaximum(*reinterpret_cast< int*>(_v)); break;
        case 19: _t->setValue(*reinterpret_cast< int*>(_v)); break;
        case 20: _t->setStep(*reinterpret_cast< int*>(_v)); break;
        case 21: _t->setPaintMargins(*reinterpret_cast< int*>(_v)); break;
        case 22: _t->setContentWidth(*reinterpret_cast< int*>(_v)); break;
        case 23: _t->setContentHeight(*reinterpret_cast< int*>(_v)); break;
        case 24: _t->setTextureWidth(*reinterpret_cast< int*>(_v)); break;
        case 25: _t->setTextureHeight(*reinterpret_cast< int*>(_v)); break;
        case 26: _t->setControl(*reinterpret_cast< QQuickItem**>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
        KQuickStyleItem *_t = static_cast<KQuickStyleItem *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 14: _t->resetHints(); break;
        default: break;
        }
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KQuickStyleItem::staticMetaObject = {
    { &QQuickItem::staticMetaObject, qt_meta_stringdata_KQuickStyleItem.data,
      qt_meta_data_KQuickStyleItem,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KQuickStyleItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KQuickStyleItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KQuickStyleItem.stringdata0))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int KQuickStyleItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 39)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 39;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 27;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 27;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 27;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 27;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 27;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KQuickStyleItem::elementTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KQuickStyleItem::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KQuickStyleItem::sunkenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KQuickStyleItem::raisedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KQuickStyleItem::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KQuickStyleItem::selectedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KQuickStyleItem::hasFocusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KQuickStyleItem::onChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KQuickStyleItem::hoverChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KQuickStyleItem::horizontalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KQuickStyleItem::transientChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KQuickStyleItem::minimumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void KQuickStyleItem::maximumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void KQuickStyleItem::stepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KQuickStyleItem::valueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void KQuickStyleItem::activeControlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void KQuickStyleItem::infoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void KQuickStyleItem::styleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void KQuickStyleItem::paintMarginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void KQuickStyleItem::hintChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void KQuickStyleItem::propertiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void KQuickStyleItem::fontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void KQuickStyleItem::controlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void KQuickStyleItem::contentWidthChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 23, _a);
}

// SIGNAL 24
void KQuickStyleItem::contentHeightChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 24, _a);
}

// SIGNAL 25
void KQuickStyleItem::textureWidthChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 25, _a);
}

// SIGNAL 26
void KQuickStyleItem::textureHeightChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 26, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
