/****************************************************************************
** Meta object code from reading C++ file 'plasmadesktoptheme.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/qqc2-desktop-style-5.43.0/kirigami-plasmadesktop-integration/plasmadesktoptheme.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plasmadesktoptheme.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_PlasmaDesktopTheme_t {
    QByteArrayData data[14];
    char stringdata0[201];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PlasmaDesktopTheme_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PlasmaDesktopTheme_t qt_meta_stringdata_PlasmaDesktopTheme = {
    {
QT_MOC_LITERAL(0, 0, 18), // "PlasmaDesktopTheme"
QT_MOC_LITERAL(1, 19, 13), // "colorsChanged"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 13), // "iconFromTheme"
QT_MOC_LITERAL(4, 48, 4), // "name"
QT_MOC_LITERAL(5, 53, 11), // "customColor"
QT_MOC_LITERAL(6, 65, 15), // "buttonTextColor"
QT_MOC_LITERAL(7, 81, 21), // "buttonBackgroundColor"
QT_MOC_LITERAL(8, 103, 16), // "buttonHoverColor"
QT_MOC_LITERAL(9, 120, 16), // "buttonFocusColor"
QT_MOC_LITERAL(10, 137, 13), // "viewTextColor"
QT_MOC_LITERAL(11, 151, 19), // "viewBackgroundColor"
QT_MOC_LITERAL(12, 171, 14), // "viewHoverColor"
QT_MOC_LITERAL(13, 186, 14) // "viewFocusColor"

    },
    "PlasmaDesktopTheme\0colorsChanged\0\0"
    "iconFromTheme\0name\0customColor\0"
    "buttonTextColor\0buttonBackgroundColor\0"
    "buttonHoverColor\0buttonFocusColor\0"
    "viewTextColor\0viewBackgroundColor\0"
    "viewHoverColor\0viewFocusColor"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PlasmaDesktopTheme[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       8,   38, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
       3,    2,   30,    2, 0x02 /* Public */,
       3,    1,   35,    2, 0x22 /* Public | MethodCloned */,

 // signals: parameters
    QMetaType::Void,

 // methods: parameters
    QMetaType::QIcon, QMetaType::QString, QMetaType::QColor,    4,    5,
    QMetaType::QIcon, QMetaType::QString,    4,

 // properties: name, type, flags
       6, QMetaType::QColor, 0x00495001,
       7, QMetaType::QColor, 0x00495001,
       8, QMetaType::QColor, 0x00495001,
       9, QMetaType::QColor, 0x00495001,
      10, QMetaType::QColor, 0x00495001,
      11, QMetaType::QColor, 0x00495001,
      12, QMetaType::QColor, 0x00495001,
      13, QMetaType::QColor, 0x00495001,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,

       0        // eod
};

void PlasmaDesktopTheme::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PlasmaDesktopTheme *_t = static_cast<PlasmaDesktopTheme *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->colorsChanged(); break;
        case 1: { QIcon _r = _t->iconFromTheme((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QIcon*>(_a[0]) = std::move(_r); }  break;
        case 2: { QIcon _r = _t->iconFromTheme((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QIcon*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (PlasmaDesktopTheme::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaDesktopTheme::colorsChanged)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        PlasmaDesktopTheme *_t = static_cast<PlasmaDesktopTheme *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QColor*>(_v) = _t->buttonTextColor(); break;
        case 1: *reinterpret_cast< QColor*>(_v) = _t->buttonBackgroundColor(); break;
        case 2: *reinterpret_cast< QColor*>(_v) = _t->buttonHoverColor(); break;
        case 3: *reinterpret_cast< QColor*>(_v) = _t->buttonFocusColor(); break;
        case 4: *reinterpret_cast< QColor*>(_v) = _t->viewTextColor(); break;
        case 5: *reinterpret_cast< QColor*>(_v) = _t->viewBackgroundColor(); break;
        case 6: *reinterpret_cast< QColor*>(_v) = _t->viewHoverColor(); break;
        case 7: *reinterpret_cast< QColor*>(_v) = _t->viewFocusColor(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject PlasmaDesktopTheme::staticMetaObject = {
    { &Kirigami::PlatformTheme::staticMetaObject, qt_meta_stringdata_PlasmaDesktopTheme.data,
      qt_meta_data_PlasmaDesktopTheme,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *PlasmaDesktopTheme::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlasmaDesktopTheme::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PlasmaDesktopTheme.stringdata0))
        return static_cast<void*>(this);
    return Kirigami::PlatformTheme::qt_metacast(_clname);
}

int PlasmaDesktopTheme::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Kirigami::PlatformTheme::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void PlasmaDesktopTheme::colorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
